import type { AllAdMgeTtTablesData, AllAdmgeTtFields } from './tableData/ttAd'

// 表格查询表单中表单项的类型
enum TableFilterType {
  Search,
  Select,
  Date,
}

// 表格字段的基本信息
interface BaseFieldInfo {
  label: string
  name: string
  state: boolean // 是否展示这个字段
}

// 选择框的选项
interface SelectFilterOptions {
  label: string
  value: any
}

// 筛选条件的基础信息
interface BaseFilterItem {
  type: TableFilterType
  label: string
  name: string
  value: any
  placeholder?: string
}

// 搜索框
interface SearchFilterItem extends BaseFilterItem {
  type: TableFilterType.Search
}

// 选择框
interface SelectFilterItem extends BaseFilterItem {
  type: TableFilterType.Select
  options: SelectFilterOptions[]
}

// 日期选择框
interface DateFilterItem extends BaseFilterItem {
  type: TableFilterType.Date
  startDate: Date
  endDate: Date
}

// 所有表格查询表单中表单项的类型
type TableFilterItem = SearchFilterItem | SelectFilterItem | DateFilterItem

// 所有表格数据的数据类型
type TableData = AllAdMgeTtTablesData

// 所有表格的字段
type TableFields = AllAdmgeTtFields

// 表格每种字段的格式
interface BaseFieldItem<T> {
  label: string
  children: T[]
}

// 查询字段需要的信息格式
interface FilterInfo {
  [key: string]: TableFilterItem
}

// 表格的props
interface TableProps {
  filtersInfo: {
    [key: string]: TableFilterItem
  }
  tableData: Array<TableData>
  // tableFields: Array<TableFields>
  tableFields: Array<BaseFieldItem<TableFields>>
  fixedFields: Array<string>
}

// 每个表格需要的信息格式，包含通用的属性
interface TableInfoItem<TData, TFields> {
  data: TData[] // 数据数组
  fields: TFields[] // 字段数组
  filters: FilterInfo // 过滤信息
  fixedFields: string[] // 固定字段
}

export { TableFilterType }
export type {
  SelectFilterOptions,
  BaseFilterItem,
  SearchFilterItem,
  SelectFilterItem,
  DateFilterItem,
  TableFilterItem,
  TableProps,
  TableData,
  FilterInfo,
  TableFields,
  TableInfoItem,
  BaseFieldInfo,
  BaseFieldItem,
}
